//
// converts from 1 bit @ 80MHz to 2 bits at 40MHz.  we use the negedge of the
// clocks here so that downstream we can use posedge everywhere
//
module htrchannel (
	input clk,						// 40MHz clock
	input clk2x,					// 80MHz clock
	input frame,					// which part of the 2-bit 40MHz word
	input chbit,					// single bit from HTR for this channel
	output reg[1:0] chlevel,	//	2-bit "level" for this channel
	output reg[3:0] chdemux		// demux of the above 2-bit level
	);

//
// latch at 80MHz.  note the "negedge" here for timing considerations
//
reg[1:0] in2;
//always @ (negedge clk2x) 
always @ (posedge clk2x) 
	if (frame) in2[0] <= #1 chbit;
	else in2[1] <= #1 chbit;
//
// now latch at 40MHz and we're done
//
//always @ (negedge clk) begin
always @ (posedge clk) begin
	chlevel <= #1 in2;
	chdemux[0] <= #1 ~( in2[0] ||  in2[1]); // demorgan's theorem
	chdemux[1] <= #1  ( in2[0] && ~in2[1]);
	chdemux[2] <= #1  (~in2[0] &&  in2[1]);
	chdemux[3] <= #1  ( in2[0] &&  in2[1]);
	end

endmodule